 


%macro rc_updt_fincen_inst_2;

/* Add gaming type code to fincen_institution */

%if %sysfunc(exist(rc_cfg.fincen_institution)) %then
%do;
   %let gaming_code_exist=N;
    proc sql noprint;
       select "Y" into :gaming_code_exist
       from  dictionary.Columns
       where  libname eq "RC_CFG"
              and  memname eq "FINCEN_INSTITUTION"
              and  name="INSTITUTION_GAMING_TYPE_CODE";
    
    %if &gaming_code_exist=N %then
    %do;
      
       alter table rc_cfg.fincen_institution 
       add 
           INSTITUTION_GAMING_TYPE_CODE char(1) label='Type of Gaming Institution', 
           INSTITUTION_GAMING_TYPE_OTHER char(50) label='Type of Gaming Institution - Other' 
       ;

       
    %end;
    
    quit;
%end;
%mend;

%macro rc_fincen_load_efile_sar;
/**********************************************************/
/* Load record level efile configuration data             */
/**********************************************************/

/* Record level configuration data */

data efile_record_config_sar;
if 0 then set rc_cfg.form_efile_record_config;

     infile  rc_tmplt(rc_fincen_sar_efile_record_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             retain form_config_key &form_config_key;
             retain form_efile_record_seq_number;
     input form_efile_record_id $
           form_efile_record_desc $
           record_sort_order
           record_length 
           source_table_name $
           source_entity_level_code  $
           source_group_name $
           page_by_field_name $
              
    ;
    drop record_sort_order  page_by_field_name;
    form_config_key=&form_config_key;
    if form_efile_record_id > '' then 
    do;     
        form_efile_record_seq_number+1;
        output;
    end;

run;
 
/* Field level configuration data */


data efile_field_config_sar;
if 0 then set rc_cfg.form_efile_field_config;

     
           
     infile  rc_tmplt(rc_fincen_sar_efile_field_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input 
           form_efile_record_id $
           target_field_start_position 
           target_field_end_position 
           target_field_short_desc $
           target_field_length
           target_field_desc $
           target_field_name   $           
           source_field_name   $
           source_field_type   $
           source_field_type_parm_list $
           source_field_default_value $
           source_field_mapped_flg $
           target_field_num_flg $           
           target_sas_format_name $
           
          
    ;
   
    form_config_key=&form_config_key;
    form_efile_field_seq_number=_n_; 


    
    drop form_efile_record_seq_number ; /* to be assigned in the next step */
     
run;
proc sql noprint;
     create table form_efile_field_config_sar as
     select a.*, b.form_efile_record_seq_number
     from efile_field_config_sar as a,
          efile_record_config_sar as b
     where a.form_efile_record_id=b.form_efile_record_id
     order by form_efile_record_seq_number,  form_efile_field_seq_number;
quit;

%if &sysrc <= 4 and &rc_debug=N %then
%do;
   proc sql;
     delete 
     from rc_cfg.form_efile_field_config
     where form_config_key=&form_config_key;

     delete 
     from rc_cfg.form_efile_record_config
     where form_config_key=&form_config_key;
   quit;

    proc append base=rc_cfg.form_efile_record_config 
                data=efile_record_config_sar force; 
    run;

    proc append base=rc_cfg.form_efile_field_config 
                data=form_efile_field_config_sar
                force; 
    run;
%end;

%mend;


%macro rc_fincen_load_mapping_sar;

/******************************************************************************/
/*  Load code mapping table                                               */
/******************************************************************************/

data code_mapping_sar;
          
     infile  rc_tmplt(rc_fincen_sar_code_mapping.csv)
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;  
   
  
   if 0 then set seg_kc.fsk_rc_form_code_mapping;
   form_config_key=&form_config_key;
   input 
            format_name $
            input_code  $
            output_code $ 
    ;
    if format_name ne '' and input_code ne '' then output;
 
run;

%if &syserr <= 4 and &rc_debug=N %then
%do;
     
     proc sql noprint;
         delete from seg_kc.fsk_rc_form_code_mapping 
     where form_config_key=&form_config_key;

     
     proc append base=seg_kc.fsk_rc_form_code_mapping (dbforce=yes) 
                data=code_mapping_sar force;
    run;

%end;
%mend;

 %macro rc_updt_sar_2;
 
   %let form_config_key=301;
   %let form_type_code=SAR;
   
   %rc_fincen_load_efile_sar;
   
   %rc_fincen_load_mapping_sar;


   %rc_efile_gen_macro_wrt_efile(form_config_key=301,
                                 form_type_code=SAR,
                                 input_or_put="put");
               
   
   
    %rc_efile_gen_macro_xpose_node( form_config_key=301,
                                    form_type_code=SAR);

    %rc_efile_gen_json_schema(form_config_key=301, 
                              form_type_code=SAR
                               );
    %rc_efile_gen_sasddl(form_config_key=301,
                         form_type_code=SAR, 
                         ddlfref=rc_tmplt,
                         outlib=rc_db);

    %rc_efile_gen_json_schema(form_config_key=301,
                              form_type_code=SAR
                           );

    %rc_efile_gen_json_default(form_config_key=301, 
                               form_type_code=SAR);

                                  
    %if %sysfunc(exist(rc_db.SAR_4A)) %then
    %do;
       %let old_column_exist=N;
        proc sql noprint;
           select "Y" into :old_column_exist
           from  dictionary.Columns
           where  libname eq "RC_DB"
                  and  memname eq "SAR_4A"
                  and  name="TAX_ID_TYPE_UNK_FLG";
        quit;
        
        %if &old_column_exist=Y %then
        %do;          
           
        proc datasets lib=rc_db nolist;
             modify SAR_4A;      
                    rename TAX_ID_TYPE_UNK_FLG=NO_SUBJECT_ID_FLG;

        quit;
        %end;    
         
          
    %end;
    %else    
    %do;
       %put RC_DB.SAR_4A is not found. All RC_DB.SAR_* tables are being regenerated;
       
       %inc rc_tmplt(SAR_ddl.sas);      
       
    %end;

    
     
%mend;

%rc_updt_fincen_inst_2;
%rc_updt_sar_2;
 


