
%macro rc_remove_form_default;

   /* Remove unused RC_CFG.FORM_DEFAULT */
   %if %sysfunc(exist(rc_cfg.form_default)) %then
   %do;
   
       proc delete lib=rc_cfg data=form_default; 
       run;
       
   %end;

%mend;

%macro rc_updt_fincen_transmitter;

   
    %let upgraded=N;
    proc sql noprint;
       select "Y" into :upgraded
       from  dictionary.Columns
       where  libname eq "RC_CFG"
              and  memname eq "FINCEN_TRANSMITTER"
              and  name="FORM_CONFIG_KEY";
    
    %if &upgraded=N %then
    %do;
      
       /* Upgrade table structure of RC_CFG.FINCEN_TRANSMITTER */

       alter table rc_cfg.fincen_transmitter
       add FORM_CONFIG_KEY numeric label='Form Key'
       add ENTITY_NUMBER char(32) label='Entity Number'   
       add ENTITY_NAME char(100) label='Entity Name'
       ;  

       alter table rc_cfg.fincen_transmitter 
       drop CURRENT_IND;
  

       /* create a transmitter for each form  */
       proc sql noprint;
            select put(max(transmitter_key),best.)  into :max_key
            from rc_cfg.fincen_transmitter;

            /* upgrade all existing transmitters (current or old) and define them as SAR transmitters */
            update rc_cfg.fincen_transmitter
            set form_config_key = 301,
                entity_name=transmitter_name,
                entity_number=transmitter_tax_id           
            ;        
           /* create the same set of transmitters for CTR and DOEP */
           create table fincen_transmitter_more as
                select monotonic() + &max_key as transmitter_key, 
                       trans.*, 
                       form.form_config_key                        
                from rc_cfg.fincen_transmitter (drop=form_config_key transmitter_key) as trans
                inner join seg_kc.fsk_rc_form_config as form
                on 1=1
                where form.form_config_key ne 301
                ;

       proc append base=rc_cfg.fincen_transmitter data=fincen_transmitter_more force;
       run;
          
    %end;
    
    quit;
 
%mend;
 

%macro rc_updt_fincen_institution;

    %let upgraded=N;
    proc sql noprint;
       select "Y" into :upgraded
       from  dictionary.Columns
       where  libname eq "RC_CFG"
              and  memname eq "FINCEN_INSTITUTION"
              and  name="DEFAULT_IND";
    
    %if &upgraded=N %then
    %do;
      
       /* Upgrade table structure of RC_CFG.FINCEN_INSTITUTION */
       alter table rc_cfg.fincen_institution 
       add DEFAULT_IND char(1) label='Default Indicator'
       add ENTITY_NUMBER char(32) label='Entity Number'
       add ENTITY_NAME char(100) label='Entity Name'
;

       alter table rc_cfg.fincen_institution 
       drop CURRENT_IND;


       /* Set all existing institutions as default institution */
       /* And populate entity_name and entity_number           */
       update rc_cfg.fincen_institution 
       set default_ind = 'Y',
           entity_name = institution_legal_name,
           entity_number = institution_id
       ;
       
    %end;    
    quit;
 
%mend;


%macro rc_updt_fincen_branch;
 
    %let upgraded=N;
    proc sql noprint;
       select "Y" into :upgraded
       from  dictionary.columns
       where  libname eq "RC_CFG"
              and  memname eq "FINCEN_BRANCH"
              and  name="PARENT_ENTITY_NUMBER";
    
    %if &upgraded=N %then
    %do;
      
        /* Upgrade table structure of RC_CFG.FINCEN_BRANCH */
       alter table rc_cfg.fincen_branch 
       add ENTITY_NUMBER char(32) label='Entity Number'   
       add ENTITY_NAME char(100) label='Entity Name'
       add PARENT_ENTITY_NUMBER  char(25) label='Parent entity ENTITY'; 


       /* use the latest institution as parent institution of all branches */
       select distinct entity_number into :institution_number 
       from rc_cfg.fincen_institution
       where form_config_key=301 and default_ind='Y'
       group by form_config_key
       having max(effective_from_date);

       update rc_cfg.fincen_branch 
       set parent_entity_number="&institution_number",
           entity_number=branch_number,
           entity_name=branch_name
       ;       
       
    %end;
   
    quit;
 
%mend;


%macro rc_fincen_load_efile_sar;
/**********************************************************/
/* Load record level efile configuration data             */
/**********************************************************/

/* Record level configuration data */

data efile_record_config_sar;
if 0 then set rc_cfg.form_efile_record_config;

     infile  rc_tmplt(rc_fincen_sar_efile_record_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             retain form_config_key &form_config_key;
             retain form_efile_record_seq_number;
     input form_efile_record_id $
           form_efile_record_desc $
           record_sort_order
           record_length 
           source_table_name $
           source_entity_level_code  $
           source_group_name $
           page_by_field_name $
              
    ;
    drop record_sort_order  page_by_field_name;
    form_config_key=&form_config_key;
    if form_efile_record_id > '' then 
    do;     
        form_efile_record_seq_number+1;
        output;
    end;

run;
 
/* Field level configuration data */

data efile_field_config_sar;
if 0 then set rc_cfg.form_efile_field_config;

     
           
     infile  rc_tmplt(rc_fincen_sar_efile_field_config.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input 
           form_efile_record_id $
           target_field_start_position 
           target_field_end_position 
           target_field_short_desc $
           target_field_length
           target_field_desc $
           target_field_name   $           
           source_field_name   $
           source_field_type   $
           source_field_type_parm_list $
           source_field_default_value $
           source_field_mapped_flg $
           target_field_num_flg $           
           target_sas_format_name $           
          
    ;
   
    form_config_key=&form_config_key;
    form_efile_field_seq_number=_n_; 


    
    drop form_efile_record_seq_number ; /* to be assigned in the next step */
     
run;
proc sql noprint;
     create table form_efile_field_config_sar as
     select a.*, b.form_efile_record_seq_number
     from efile_field_config_sar as a,
          efile_record_config_sar as b
     where a.form_efile_record_id=b.form_efile_record_id
     order by form_efile_record_seq_number,  form_efile_field_seq_number;
quit;

%if &sysrc <= 4  %then
%do;
   proc sql;
     delete 
     from rc_cfg.form_efile_field_config
     where form_config_key=&form_config_key;

     delete 
     from rc_cfg.form_efile_record_config
     where form_config_key=&form_config_key;

   quit;

    proc append base=rc_cfg.form_efile_record_config 
                data=efile_record_config_sar force; 
    run;

    proc append base=rc_cfg.form_efile_field_config 
                data=form_efile_field_config_sar
                force; 
    run;
%end;

%mend;

%macro rc_fincen_load_error_code_sar;

/****************************************************************/
/* Load FINCEN SAR error codes                                  */
/****************************************************************/


data rc_cfg.sar_fincen_error_code;

     attrib ERROR_CODE  length=$4 label='Error Code'
            ERROR_DESC length=$4000 label='Error Description'
            ERROR_RECORD_TYPE length=$2 label='Record Type'
            ERROR_TYPE_CODE length=$1 label='Error Type'
     ;
      
      infile  rc_tmplt(rc_fincen_sar_error_code.csv)  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
             
     input error_code $
           error_desc $
           error_record_type $
           error_type_code $
                     
    ;
run;

%mend;

%macro updt_sar_table; 
 %if %sysfunc(exist(rc_db.SAR_2B)) %then
    %do;
       %let new_column_exist=N;
        proc sql noprint;
           select "Y" into :new_column_exist
           from  dictionary.Columns
           where  libname eq "RC_DB"
                  and  memname eq "SAR_2B"
                  and  name="INSTITUTION_NUMBER";
        quit;
        
        %if &new_column_exist=N %then
        %do;          
           
        proc sql; 
             alter table RC_DB.SAR_2B      
                   add INSTITUTION_NUMBER char(10) label="Financial Institution Location Code"
             ;

        quit;
        
        proc sql;
             update RC_DB.SAR_2B 
             set institution_number=institution_id;
        quit;
        
        %end;    
         
          
    %end;
    %else    
    %do;
       %put RC_DB.SAR_2B is not found. All RC_DB.SAR_* tables are being regenerated;
       
       %inc rc_tmplt(SAR_ddl.sas);      
       
    %end;
%mend;

 
%macro rc_updt_sar_3;
 
   /* add institutionId to report json */
   %let form_config_key=301;
   %let form_type_code=SAR;
   
   %rc_fincen_load_error_code_sar; 

   %rc_fincen_load_efile_sar;      

   %rc_efile_gen_macro_xpose_node( form_config_key=301,
                                    form_type_code=SAR);

    %rc_efile_gen_macro_wrt_efile(form_config_key=301,
                                 form_type_code=SAR,
                                 input_or_put="put");

    %rc_efile_gen_json_schema(form_config_key=301,
                              form_type_code=SAR
                           );

    %rc_efile_gen_json_default(form_config_key=301, 
                               form_type_code=SAR);

    %rc_efile_gen_sasddl(form_config_key=301,
                         form_type_code=SAR, 
                         ddlfref=rc_tmplt,
                         outlib=rc_db);

    %updt_sar_table;
     
%mend;


%rc_remove_form_default;
 
%rc_updt_fincen_transmitter;
%rc_updt_fincen_institution;
%rc_updt_fincen_branch;

%rc_refresh_entity_info;

%rc_updt_sar_3;
 
 


