/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_fincen_config_update_4.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Program to update regulatory console configuration data in hotfix 4.
+------------------------------------------------------------------------------+
| USAGE:   Run this program using UTF-8 SAS.
+-------------+----------------------------------------------------------------+
| COMMENTS    | This program is executed by the regulatory console deployment scripts.
+-------------+----------+----------+------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2018 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/

%macro rc_updt_fincen_branch;
    /* Add branch Tax Id unknown flag  */
    %let upgraded=N;
    proc sql noprint;
       select "Y" into :upgraded
       from  dictionary.columns
       where  libname eq "RC_CFG"
              and  memname eq "FINCEN_BRANCH"
              and  name="BRANCH_TAX_ID_UNKNOWN_FLAG";
    
    %if &upgraded=N %then
    %do;
      
       /* Upgrade table structure of RC_CFG.FINCEN_BRANCH */
       alter table rc_cfg.fincen_branch 
       add BRANCH_TAX_ID_UNKNOWN_FLAG char(1) label='Branch Tax Id Unknown'
       ; 
       quit; 
       
    %end;

 
%mend;

%rc_updt_fincen_branch;

%macro rc_updt_fincen_inst_contact;
    /* Increase CONTACT_OFFICE to char(150)  */
    %let increased=N;
    proc sql noprint;
       select "Y" into :increased
       from  dictionary.columns
       where  libname eq "RC_CFG"
              and  memname eq "FINCEN_INSTITUTION"
              and  name="CONTACT_OFFICE"
              and  length=150;
    %if &increased=N %then
    %do;
      
       /* Upgrade table structure of RC_CFG.FINCEN_BRANCH */
       alter table rc_cfg.fincen_institution 
       modify CONTACT_OFFICE char(150)
       ; 
       quit; 
       
    %end;
 
%mend;

%rc_updt_fincen_inst_contact;

 


